<?php
/**
 * Déclarations relatives à la base de données
 *
 * @plugin     Autorisations étendues
 * @copyright  2020
 * @author     tofulm
 * @licence    GNU/GPL
 * @package    SPIP\Auted\Pipelines
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Déclaration des alias de tables et filtres automatiques de champs
 *
 * @pipeline declarer_tables_interfaces
 * @param array $interfaces
 *     Déclarations d'interface pour le compilateur
 * @return array
 *     Déclarations d'interface pour le compilateur
 */
function auted_declarer_tables_interfaces($interfaces) {

	$interfaces['table_des_tables']['aut_mods'] = 'aut_mods';

	return $interfaces;
}


/**
 * Déclaration des objets éditoriaux
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 *     Description des tables
 * @return array
 *     Description complétée des tables
 */
function auted_declarer_tables_objets_sql($tables) {

	$tables['spip_aut_mods'] = array(
		'type' => 'aut_mod',
		'principale' => 'oui',
		'table_objet_surnoms' => array('autmod'), // table_objet('aut_mod') => 'aut_mods'
		'field'=> array(
			'id_aut_mod'         => 'bigint(21) NOT NULL',
			'nom'                => 'varchar(55) NOT NULL DEFAULT ""',
			'modele'             => 'text NOT NULL DEFAULT ""',
			'statut'             => 'varchar(20)  DEFAULT "0" NOT NULL',
			'maj'                => 'TIMESTAMP'
		),
		'key' => array(
			'PRIMARY KEY'        => 'id_aut_mod',
			'KEY statut'         => 'statut',
		),
		'titre' => 'nom AS titre, "" AS lang',
		 #'date' => '',
		'champs_editables'  => array('nom', 'modele'),
		'champs_versionnes' => array(),
		'rechercher_champs' => array(),
		'tables_jointures'  => array(),
		'statut_textes_instituer' => array(
			'prepa'    => 'texte_statut_en_cours_redaction',
			'publie'   => 'texte_statut_publie',
			'refuse'   => 'texte_statut_refuse',
			'poubelle' => 'texte_statut_poubelle',
		),
		'statut'=> array(
			array(
				'champ'     => 'statut',
				'publie'    => 'publie',
				'previsu'   => 'publie,prepa',
				'post_date' => 'date',
				'exception' => array('statut','tout')
			)
		),
		'texte_changer_statut' => 'aut_mod:texte_changer_statut_aut_mod',


	);

	return $tables;
}


/**
 * Ajouter des champs aux tables auteurs et articles et rubrique
 * @param array $tables_principales
 * @return array
 */

function auted_declarer_tables_principales($tables_principales){

	$tables_principales['spip_auteurs']['field']['autorisations'] = "text NOT NULL";

	return $tables_principales;
}
